@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0800';
+our $VERSION = '0.0900';
 
 use strict;
 use warnings;
@@ -19,6 +19,7 @@ our @EXPORT = qw(
     set_chan_patch
     set_time_sig
     setup_score
+    dura_size
 );
 
 use constant TICKS => 96;
@@ -200,6 +201,19 @@ sub set_time_sig {
     );
 }
 
+
+sub dura_size {
+    my ($duration) = @_;
+    my $size = 0;
+    if ($duration =~ /^d(\d+)$/) {
+        $size = sprintf '%0.f', $1 / TICKS;
+    }
+    else {
+        $size = $MIDI::Simple::Length{$duration};
+    }
+    return $size;
+}
+
 1;
 
 __END__
@@ -214,7 +228,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0800
+version 0.0900
 
 =head1 SYNOPSIS
 
@@ -223,6 +237,8 @@ version 0.0800
   my $dump = midi_dump('volume'); # length, etc.
   print Dumper $dump;
 
+  my $size = dura_size('dqn');
+
   my $score = setup_score( bpm => 120, etc => '...', );
 
   set_time_sig( $score, '5/4' );
@@ -320,6 +336,13 @@ L<MIDI::Simple> C<s> and C<f> respectively.
 
 Set the B<score> C<time_signature> based on the given string.
 
+=head2 dura_size
+
+  $size = dura_size($duration);
+
+Return the B<duration> size based on the L<MIDI::Simple> C<Length>
+value (e.g. C<hn>, C<ten>) or number of ticks (if given as C<d###>).
+
 =head1 SEE ALSO
 
 The F<t/01-functions.t> test file in this distribution
@@ -336,7 +359,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Gene Boggs.
+This software is copyright (c) 2021 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
